import { Mat3, Mat4 } from './mat.ts';
import { Quat } from './quat.ts';
import { Vec2, Vec3 } from './vec.ts';
/** Returns a {@link Mat3} for a 2D point translated by (x, y). */
export declare function translation2d(v: Vec2, out?: Mat3): Mat3;
/** Returns a {@link Mat3} for a 2D point scaled by (x, y). */
export declare function scaling2d(v: Vec2, out?: Mat3): Mat3;
/** Returns a {@link Mat3} for a 2D point rotated in couterclockwise direction. */
export declare function rotation2d(angle: number, out?: Mat3): Mat3;
/**
 * Returns a {@link Mat3} for transformation in TRS order (= translation * rotation * scale).
 * @returns out = translation * rotation * scale
 */
export declare function transformation2d(translate: Vec2, rotateAngle: number, scale: Vec2, out?: Mat3): Mat3;
/** Return a {@link Mat4} for a 3D point translated by (x, y, z). */
export declare function translation(v: Vec3, out?: Mat4): Mat4;
/** Return a {@link Mat4} for a 3D point scaled by (x, y, z). */
export declare function scaling(v: Vec3, out?: Mat4): Mat4;
/** Returns a {@link Mat4} for a rotation by a {@link Quat}. */
export declare function rotation(q: Quat, out?: Mat4): Mat4;
/** Extract the {@link Vec3} translation component from a transformation matrix. */
export declare function translationOf(m: Mat4, out?: Vec3): Vec3;
/**
 * Extract the {@link Vec3} scaling components from a transformation matrix
 * in TRS order (= translation * rotation * scale).
 */
export declare function scalingOf(m: Mat4, out?: Vec3): Vec3;
/**
 * Extract the {@link Quat} rotation components from a transformation matrix
 * in TRS order (= translation * rotation * scale).
 * @see https://en.wikipedia.org/wiki/Rotation_matrix#Quaternion
 */
export declare function rotationOf(trs: Mat4, out?: Quat): Quat;
/**
 * Returns a {@link Mat4} for transformation in TRS order (= translation * rotation * scale).
 * @returns out = translation * rotation * scale
 */
export declare function transformation(translate: Vec3, rotate: Quat, scale: Vec3, out?: Mat4): Mat4;
/**
 * Returns the inverse of a {@link Mat4} that is assumed to represent a valid transformation
 * in TRS order (= translation * rotation * scale).
 * This function is more efficient than {@link Mat4.invert} by using the properties of a TRS matrix.
 * @returns out = M^-1
 */
export declare function inverseTRS(trs: Mat4, out?: Mat4): boolean;
/**
 * Calculate the {@link Mat4} orthographic projection matrix.
 * To apply a glTF orthographic camera, use: left = -xmag, right = xmag, bottom = -ymag, top = ymag.
 * @see https://en.wikipedia.org/wiki/Orthographic_projection
 * @see https://github.com/KhronosGroup/glTF/tree/master/specification/2.0
 */
export declare function ortho(left: number, right: number, bottom: number, top: number, znear: number, zfar: number, out?: Mat4): Mat4;
/**
 * Calculate the {@link Mat4} perspective projection using glTF's formula. Use infinite projection if zfar = Infinity.
 * @see https://github.com/KhronosGroup/glTF/tree/master/specification/2.0
 */
export declare function perspective(aspect: number, yfov: number, znear: number, zfar: number, out?: Mat4): Mat4;
/** Calculate the {@link Mat4} perspective projection from a viewport. Use infinite projection if zfar = Infinity. */
export declare function perspectiveViewport(left: number, right: number, bottom: number, top: number, znear: number, zfar: number, out?: Mat4): Mat4;
/**
 * Calculate the {@link Mat4} model matrix for a camera at eye position looking at the center
 * position with a given up direction.
 */
export declare function targetTo(eye: Vec3, center: Vec3, up: Vec3, out?: Mat4): Mat4;
/**
 * Calculate the {@link Mat4} view matrix for a camera at eye position looking at the center
 * position with a given up direction.
 */
export declare function lookAt(eye: Vec3, center: Vec3, up: Vec3, out?: Mat4): Mat4;
/**
 * Calculate the look-at direction {@link Vec3} vector from pitch (up/down) and yaw (left/right) angles in radians.
 * It looks towards -Z axis when pitch = 0 and yaw = 0.
 * This can be used with lookAt method to build an FPS camera view matrix by:
 * viewMatrix = lookAt(eye, lookAtDir(yaw, pitch).add(eye), new Vec3(0, 1, 0));
 */
export declare function lookAtDir(pitch: number, yaw: number, out?: Vec3): Vec3;
//# sourceMappingURL=transform.d.ts.map