/** A linear memory manager. */
export interface MemoryManager {
    /** The active memory buffer. */
    readonly buffer: ArrayBufferLike;
    /** The active float64 memory view. */
    readonly view: Float64Array;
    /** Allocates given size of memory in the number of float64 and returns the byteOffset pointing to the new memory. */
    create(size: number): number;
    /** Frees the memory at given byteOffset and size in the number of float64. */
    free(byteOffset: number, size: number): void;
}
/** Sets the {@link MemoryManager} to use. */
export declare function setMemoryManager(manager: MemoryManager): void;
/** Sets if FinalizationRegistry should be used for automatic memory cleanup. */
export declare function useFinalizationRegistry(use: boolean): void;
/** A wrapped TypedArray that requires explicit memory management. */
export interface ManagedBufferView<N extends number = number> extends ArrayBufferView, Disposable {
    /** Whether the array is still valid. */
    readonly valid: boolean;
    /** The length of the array. */
    readonly length: N;
    /** Frees the array. */
    free(): void;
}
/** A managed Float64Array. */
export declare abstract class ManagedFloat64Array<N extends number = number> implements ManagedBufferView<N>, Iterable<number> {
    byteOffset: number;
    constructor(byteOffset: number);
    [Symbol.iterator](): Iterator<number>;
    [Symbol.dispose](): void;
    /** Gets the value at given index. */
    at(index: number): number | undefined;
    /** Sets the value at given index. */
    setAt(index: number, value: number): void;
    /** Copies a managed array to this. */
    copy(from: ManagedFloat64Array, dstOffset?: number, srcOffset?: number, length?: number): void;
    /** Copies an array to this. */
    set(array: ArrayLike<number>, offset?: number): void;
    free(): void;
    get buffer(): ArrayBufferLike;
    get byteLength(): number;
    get valid(): boolean;
    abstract readonly length: N;
}
//# sourceMappingURL=memory.d.ts.map